@@ -44,7 +44,7 @@ __author__ = 'Álan Crístoffer'
 __copyright__ = 'Copyright 2016, Álan Crístoffer'
 __credits__ = ['Álan Crístoffer']
 __license__ = 'MIT'
-__version__ = '1.0.3'
+__version__ = '1.0.5'
 __maintainer__ = 'Álan Crístoffer'
 __email__ = 'acristoffers@gmail.com'
 __status__ = 'Release'
@@ -54,6 +54,11 @@ Direction = Enum('Direction', 'Output Input')
 LogicValue = Enum('LogicValue', 'Low High')
 
 
+def add_path(path):
+    """Adds a directory to the list of folders where to load drivers from"""
+    drivers.add_path(path)
+
+
 def list_available_drivers():
     """Returns a list of string with the names of available drivers.
 
